### Name: profile.gnm
### Title: Profile Deviance for Parameters in a Generalized Nonlinear Model
### Aliases: profile.gnm plot.profile.gnm
### Keywords: models nonlinear

### ** Examples

### Example in which deviance is near quadratic
data(voting)
count <- with(voting, percentage/100 * total)
yvar <- cbind(count, voting$total - count)
classMobility <- gnm(yvar ~ -1 + Nonlin(Dref(origin, destination)),
                     constrain = "[.]origin", family = binomial,
                     data = voting)
prof <- profile(classMobility, trace = TRUE)
plot(prof)
## confint similar to MLE +/- 1.96*s.e. 
confint(prof, trace = TRUE)
coefData <- se(classMobility)
cbind(coefData[1] - 1.96 * coefData[2], coefData[1] + 1.96 * coefData[2])

## Not run: 
##D ### These examples take longer to run
##D ### Another near quadratic example
##D data(occupationalStatus)
##D RChomog <- gnm(Freq ~ origin + destination + Diag(origin, destination) +
##D                Nonlin(MultHomog(origin, destination)),
##D                ofInterest = "MultHomog", constrain = "MultHomog.*1",
##D                family = poisson, data = occupationalStatus)
##D prof <- profile(RChomog, trace = TRUE)
##D plot(prof)
##D ## confint similar to MLE +/- 1.96*s.e. 
##D confint(prof)
##D coefData <- se(RChomog)
##D cbind(coefData[1] - 1.96 * coefData[2], coefData[1] + 1.96 * coefData[2])
##D 
##D ### An example showing asymptotic deviance
##D data(yaish)
##D unidiff <- gnm(Freq ~ educ*orig + educ*dest +
##D                Mult(Exp(-1 + educ), -1 + orig:dest),
##D                ofInterest = "Mult.*educ", constrain = "Mult.*educ1",
##D                family = poisson, data = yaish, subset = (dest != 7))
##D prof <- profile(unidiff, trace = TRUE)
##D plot(prof)
##D ## clearly not quadratic for Mult1.Factor1.educ4 or Mult1.Factor1.educ5!
##D confint(prof)
##D ##                          2.5 %     97.5 %
##D ## Mult1.Factor1.educ1         NA         NA
##D ## Mult1.Factor1.educ2 -0.5978901  0.1022447
##D ## Mult1.Factor1.educ3 -1.4836854 -0.2362378
##D ## Mult1.Factor1.educ4 -2.5792398 -0.2953420
##D ## Mult1.Factor1.educ5       -Inf -0.7006889
##D ## coefData <- se(unidiff)
##D ## cbind(coefData[1] - 1.96 * coefData[2], coefData[1] + 1.96 * coefData[2])
##D 
##D ### A far from quadratic example, also with eliminated parameters
##D data(backPain)
##D backPainLong <- expandCategorical(backPain, "pain")
##D 
##D oneDimensional <- gnm(count ~ pain + Mult(pain - 1, x1 + x2 + x3 - 1),
##D                       eliminate = id,  family = "poisson",
##D                       constrain = "Mult.*(worse|x1)", constrainTo = c(0, 1),
##D                       data = backPainLong)
##D prof <- profile(oneDimensional, trace = TRUE)
##D plot(prof)
##D ## not quadratic for any non-eliminated parameter
##D confint(prof)
##D coefData <- se(oneDimensional)
##D cbind(coefData[1] - 1.96 * coefData[2], coefData[1] + 1.96 * coefData[2])
## End(Not run)



